.. image:: https://arvoelke.github.io/nengolib-docs/_static/logo.png
   :width: 64
   :height: 64
   :target: https://github.com/arvoelke/nengolib
   :alt: Nengolib Logo

.. image:: https://travis-ci.org/arvoelke/nengolib.svg?branch=master
   :target: https://travis-ci.org/arvoelke/nengolib
   :alt: Build Status

.. image:: https://codecov.io/github/arvoelke/nengolib/coverage.svg?branch=master
   :target: https://codecov.io/github/arvoelke/nengolib?branch=master
   :alt: Code Coverage

import nengolib
===============

Additional extensions and tools for modelling dynamical systems in
`Nengo <https://github.com/nengo/nengo>`__.


`Documentation <https://arvoelke.github.io/nengolib-docs/>`__
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

This project's documentation is hosted on GitHub.IO:
https://arvoelke.github.io/nengolib-docs/.


Development
~~~~~~~~~~~

To install the development version of nengolib::

    git clone https://github.com/arvoelke/nengolib
    cd nengolib
    python setup.py develop

Notebooks can be run manually in ``docs/notebooks`` by running::

    pip install jupyter
    jupyter notebook
